@@ -2,9 +2,9 @@ import fs from "fs";
 import commonjs from "@rollup/plugin-commonjs";
 import resolve from "@rollup/plugin-node-resolve";
 import svelte from "rollup-plugin-svelte";
-// import { terser } from "rollup-plugin-terser";
 import typescript from "@rollup/plugin-typescript";
-import autoPreprocess from "svelte-preprocess";
+import css from "rollup-plugin-css-only";
+import sveltePreprocess from "svelte-preprocess";
 
 const production = !process.env.ROLLUP_WATCH;
 
@@ -35,15 +35,15 @@ export default [
     },
     plugins: [
       svelte({
-        // enable run-time checks when not in production
-        dev: !production,
-        preprocess: autoPreprocess(),
-        // we'll extract any component CSS out into
-        // a separate file - better for performance
-        css: (css) => {
-          css.write("svelte-bundle.css");
+        preprocess: sveltePreprocess({ sourceMap: !production }),
+        compilerOptions: {
+          // enable run-time checks when not in production
+          dev: !production,
         },
       }),
+      // we'll extract any component CSS out into
+      // a separate file - better for performance
+      css({ output: "svelte-bundle.css" }),
       // If you have external dependencies installed from
       // npm, you'll most likely need these plugins. In
       // some cases you'll need additional configuration -
@@ -54,17 +54,11 @@ export default [
         dedupe: ["svelte"],
         preferBuiltins: false,
       }),
-      typescript(),
       commonjs(),
-      // In dev mode, call `npm run start` once
-      // the bundle has been generated
-      // !production && serve(),
-      // Watch the `public` directory and refresh the
-      // browser on changes when not in production
-      // !production && livereload("public"),
-      // If we're building for production (npm run build
-      // instead of npm run dev), minify
-      // production && terser(),
+      typescript({
+        sourceMap: !production,
+        inlineSources: !production,
+      }),
       copyFile({ src: "src/backend/index.html", dest: "build/index.html" }),
     ],
     watch: {
