@@ -674,7 +674,7 @@ def configure(ctx: click.Context, promptless: bool) -> Config:
         ).unsafe_ask()
         game_flavour = select(
             'Game flavour:',
-            choices=sorted(Flavour.__members__, reverse=not Config.is_classic_folder(addon_dir)),
+            choices=sorted(Flavour, reverse=Config.infer_flavour(addon_dir) is Flavour.retail),
         ).unsafe_ask()
         constructor = partial(Config, addon_dir=addon_dir, game_flavour=game_flavour)
 
@@ -707,7 +707,7 @@ def list_installed_wago_auras(obj: ManagerWrapper) -> None:
     config = BuilderConfig()
     aura_groups = WaCompanionBuilder(obj.m, config).extract_installed_auras()
     installed_auras = sorted(
-        (g._filename, fill(a.id, width=30, max_lines=1), a.url)
+        (g.filename, fill(a.id, width=30, max_lines=1), a.url)
         for g in aura_groups
         for v in g.__root__.values()
         for a in v
