@@ -37,6 +37,7 @@ from .resolvers import (
     InstawowResolver,
     Resolver,
     Strategy,
+    TownlongYakResolver,
     TukuiResolver,
     WowiResolver,
     normalise_names,
@@ -65,9 +66,8 @@ if TYPE_CHECKING:
     from yarl import URL
 
     _T = TypeVar('_T')
-    _FT = TypeVar('_FT', bound=Callable[..., Any])
+    _C = TypeVar('_C', bound=Callable[..., Awaitable[object]])
     _TManager = TypeVar('_TManager', bound='Manager')
-
     _BaseResolverDict: TypeAlias = 'dict[str, Resolver]'
 else:
     _BaseResolverDict = dict
@@ -76,14 +76,14 @@ else:
 USER_AGENT = 'instawow (https://github.com/layday/instawow)'
 
 
-AsyncNamedTemporaryFile = t(NamedTemporaryFile)
-copy_async = t(copy)
-move_async = t(move)
+_AsyncNamedTemporaryFile = t(NamedTemporaryFile)
+_copy_async = t(copy)
+_move_async = t(move)
 
 
 @asynccontextmanager
 async def _open_temp_writer() -> AsyncIterator[tuple[Path, Callable[[bytes], Awaitable[int]]]]:
-    fh = await AsyncNamedTemporaryFile(delete=False)
+    fh = await _AsyncNamedTemporaryFile(delete=False)
     path = Path(fh.name)
     try:
         yield (path, t(fh.write))
@@ -115,7 +115,7 @@ def _open_archive(path: PurePath) -> Iterator[tuple[set[str], Callable[[Path], N
         yield (base_dirs, extract)
 
 
-async def download_archive(manager: Manager, pkg: Pkg, *, chunk_size: int = 4096) -> Path:
+async def _download_archive(manager: Manager, pkg: Pkg, *, chunk_size: int = 4096) -> Path:
     url = pkg.download_url
     dest = manager.config.cache_dir / shasum(
         pkg.source, pkg.id, pkg.version, manager.config.game_flavour
@@ -123,7 +123,7 @@ async def download_archive(manager: Manager, pkg: Pkg, *, chunk_size: int = 4096
     if await t(dest.exists)():
         logger.debug(f'retrieving {url} from cache at {dest}')
     elif url.startswith('file://'):
-        await copy_async(file_uri_to_path(url), dest)
+        await _copy_async(file_uri_to_path(url), dest)
     else:
         async with manager.web_client.get(
             url, raise_for_status=True, trace_request_ctx={'report_progress': True}
@@ -134,7 +134,7 @@ async def download_archive(manager: Manager, pkg: Pkg, *, chunk_size: int = 4096
             async for chunk in response.content.iter_chunked(chunk_size):
                 await write(chunk)
 
-        await move_async(temp_path, dest)
+        await _move_async(temp_path, dest)
 
     return dest
 
@@ -188,7 +188,7 @@ def _should_migrate(engine: Any) -> bool:
             return not current
 
 
-def prepare_database(config: Config) -> sqlalchemy.orm.sessionmaker:
+def prepare_database(config: Config) -> sqlalchemy.orm.Session:
     from sqlalchemy import create_engine
     from sqlalchemy.orm import sessionmaker
 
@@ -221,7 +221,7 @@ def prepare_database(config: Config) -> sqlalchemy.orm.sessionmaker:
                 ModelBase.metadata.create_all(engine)
                 stamp(alembic_config, DB_REVISION)
 
-    return sessionmaker(bind=engine)
+    return sessionmaker(bind=engine)()
 
 
 def init_web_client(**kwargs: Any) -> aiohttp.ClientSession:
@@ -281,14 +281,13 @@ class _DummyLock:
 def _with_lock(
     lock_name: str,
     manager_bound: bool = True,
-) -> Callable[[_FT], _FT]:
-    def outer(coro_fn: _FT):
+) -> Callable[[_C], _C]:
+    def outer(coro_fn: _C) -> _C:
         async def inner(self: Manager, *args: object, **kwargs: object):
-            key = f'{id(self)}_{lock_name}' if manager_bound else lock_name
-            async with self.locks[key]:
+            async with self.locks[f'{id(self)}_{lock_name}' if manager_bound else lock_name]:
                 return await coro_fn(self, *args, **kwargs)
 
-        return inner
+        return inner  # type: ignore
 
     return outer
 
@@ -308,55 +307,51 @@ class Manager:
         TukuiResolver,
         GithubResolver,
         InstawowResolver,
+        TownlongYakResolver,
     )
 
     def __init__(
         self,
         config: Config,
         database: sqlalchemy.orm.Session,
-        *,
-        web_client: aiohttp.ClientSession | None = None,
-        locks: defaultdict[str, asyncio.Lock] | None = None,
     ) -> None:
         self.config = config
         self.database = database
 
         plugin_hook = load_plugins()
         resolver_classes = chain(
-            self.RESOLVERS, (r for g in plugin_hook.instawow_add_resolvers() for r in g)
+            (r for g in plugin_hook.instawow_add_resolvers() for r in g), self.RESOLVERS
         )
         self.resolvers = _ResolverDict((r.source, r(self)) for r in resolver_classes)
 
-        if web_client is not None:
-            self.web_client = web_client
-        if locks is not None:
-            self.locks = locks
-
         self._catalogue = None
 
     @classmethod
-    def from_config(cls: type[_TManager], config: Config, **kwargs: Any) -> _TManager:
-        session_factory = prepare_database(config)
-        return cls(config, session_factory(), **kwargs)
+    def contextualise(
+        cls,
+        *,
+        web_client: aiohttp.ClientSession | None = None,
+        locks: defaultdict[str, asyncio.Lock] | None = None,
+    ) -> None:
+        if web_client is not None:
+            _web_client.set(web_client)
+        if locks is not None:
+            _locks.set(locks)
+
+    @classmethod
+    def from_config(cls: type[_TManager], config: Config) -> _TManager:
+        return cls(config, prepare_database(config))
 
     @property
     def web_client(self) -> aiohttp.ClientSession:
         "The web client session."
         return _web_client.get()
 
-    @web_client.setter
-    def web_client(self, value: aiohttp.ClientSession) -> None:
-        _web_client.set(value)
-
     @property
     def locks(self) -> defaultdict[str, asyncio.Lock]:
         "Lock factory used to synchronise async operations."
         return _locks.get()
 
-    @locks.setter
-    def locks(self, value: defaultdict[str, asyncio.Lock]) -> None:
-        _locks.set(value)
-
     def pair_uri(self, value: str) -> tuple[str, str] | None:
         "Attempt to extract the package source and alias from a URI."
 
@@ -592,7 +587,7 @@ class Manager:
             compress(resolve_results.items(), (not self.get_pkg(d) for d in resolve_results))
         )
         installables = {
-            (d, r): download_archive(self, r) for d, r in resolve_results.items() if is_pkg(r)
+            (d, r): _download_archive(self, r) for d, r in resolve_results.items() if is_pkg(r)
         }
         archives = await gather(installables.values(), capture_manager_exc_async)
         results = chain_dict(
@@ -633,7 +628,7 @@ class Manager:
         }
         installables = {d: r for d, r in resolve_results.items() if is_pkg(r)}
         updatables = {
-            (d, o, n): download_archive(self, n)
+            (d, o, n): _download_archive(self, n)
             for d, n in installables.items()
             for d, o, n in ((d, defns_to_pkgs[d], n),)
             if n.version != o.version
@@ -674,7 +669,16 @@ class Manager:
         return results
 
     @_with_lock('change state')
-    async def pin(self, defns: Sequence[Defn]) -> dict[Defn, E.ManagerResult]:
+    async def pin(
+        self, defns: Sequence[Defn]
+    ) -> dict[
+        Defn,
+        E.PkgNotInstalled
+        | E.PkgInstalled
+        | E.PkgStrategyUnsupported
+        | E.ManagerError
+        | E.InternalError,
+    ]:
         """Pin and unpin installed packages.
 
         instawow does not have true pinning.  This sets the strategy
@@ -687,7 +691,9 @@ class Manager:
 
         strategies = frozenset({Strategy.default, Strategy.version})
 
-        def pin(defn: Defn, pkg: Pkg | None) -> E.ManagerResult:
+        def pin(
+            defn: Defn, pkg: Pkg | None
+        ) -> E.PkgNotInstalled | E.PkgInstalled | E.PkgStrategyUnsupported:
             if not pkg:
                 return E.PkgNotInstalled()
             elif {defn.strategy} <= strategies <= self.resolvers[pkg.source].strategies:
@@ -697,7 +703,7 @@ class Manager:
             else:
                 return E.PkgStrategyUnsupported(Strategy.version)
 
-        return {d: pin(d, self.get_pkg(d)) for d in defns}
+        return {d: await capture_manager_exc_async(t(pin)(d, self.get_pkg(d))) for d in defns}
 
 
 def _extract_filename_from_hdr(response: aiohttp.ClientResponse) -> str:
@@ -768,9 +774,10 @@ class CliManager(Manager):
 
             async def run():
                 tickers = set()
-                async with _init_cli_web_client(bar, tickers) as self.web_client, _cancel_tickers(
+                async with _init_cli_web_client(bar, tickers) as web_client, _cancel_tickers(
                     tickers
                 ):
+                    self.contextualise(web_client=web_client)
                     return await awaitable
 
             loop = asyncio.new_event_loop()
