@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from datetime import datetime, timezone
-from typing import TYPE_CHECKING, List, Optional as O
+from typing import TYPE_CHECKING
 
 from sqlalchemy import (
     Column,
@@ -27,20 +27,22 @@ else:
 class TZDateTime(TZDateTime_base_class):
     impl = DateTime
 
-    def process_bind_param(self, value: O[datetime], dialect: object) -> O[datetime]:  # type: ignore
+    def process_bind_param(  # type: ignore
+        self, value: datetime | None, dialect: object
+    ) -> datetime | None:
         if value is not None:
             if not value.tzinfo:
                 raise TypeError('tzinfo is required')
             value = value.astimezone(timezone.utc).replace(tzinfo=None)
         return value
 
-    def process_result_value(self, value: O[datetime], dialect: object) -> O[datetime]:
+    def process_result_value(self, value: datetime | None, dialect: object) -> datetime | None:
         if value is not None:
             value = value.replace(tzinfo=timezone.utc)
         return value
 
     @property
-    def python_type(self):
+    def python_type(self) -> type[datetime]:
         return datetime
 
 
@@ -66,13 +68,13 @@ class Pkg(ModelBase):
     download_url = Column(String, nullable=False)
     date_published = Column(TZDateTime, nullable=False)
     version = Column(String, nullable=False)
-    folders: relationship[List[PkgFolder]] = relationship(
+    folders: relationship[list[PkgFolder]] = relationship(
         'PkgFolder', cascade='all, delete-orphan', backref='pkg'
     )
     options: relationship[PkgOptions] = relationship(
         'PkgOptions', cascade='all, delete-orphan', uselist=False
     )
-    deps: relationship[List[PkgDep]] = relationship(
+    deps: relationship[list[PkgDep]] = relationship(
         'PkgDep', cascade='all, delete-orphan', backref='pkg'
     )
 
@@ -90,15 +92,15 @@ class Pkg(ModelBase):
             download_url: str,
             date_published: datetime,
             version: str,
-            folders: List[PkgFolder] = [],
+            folders: list[PkgFolder] = [],
             options: PkgOptions,
-            deps: List[PkgDep] = [],
+            deps: list[PkgDep] = [],
         ) -> None:
             ...
 
     @property
-    def logged_versions(self) -> List[PkgVersionLog]:
-        session: O[Session] = object_session(self)
+    def logged_versions(self) -> list[PkgVersionLog]:
+        session: Session | None = object_session(self)
         return (
             (
                 session.query(PkgVersionLog)
