@@ -3,10 +3,10 @@ from __future__ import annotations
 from collections.abc import AsyncIterator, Sequence, Set
 from datetime import datetime, timezone
 from enum import Enum
-from itertools import chain, count, takewhile
+from itertools import chain, takewhile
 import re
 import typing
-from typing import TYPE_CHECKING, Any, ClassVar, cast
+from typing import TYPE_CHECKING, Any, ClassVar
 
 from pydantic import BaseModel
 from pydantic.datetime_parse import parse_datetime
@@ -58,10 +58,10 @@ class Defn(_HashableModel):
             version=pkg.version,
         )
 
-    def __init__(self, source: str, alias: str, **kwargs: Any) -> None:
+    def __init__(self, source: str, alias: str, **kwargs: object) -> None:
         super().__init__(source=source, alias=alias, **kwargs)
 
-    def with_(self, **kwargs: Any) -> Defn:
+    def with_(self, **kwargs: object) -> Defn:
         return self.__class__(**{**self.__dict__, **kwargs})
 
     def with_strategy(self, strategy: Strategy) -> Defn:
@@ -93,10 +93,10 @@ class _CatalogueEntryDefaultFields(TypedDict):
     id: str
     slug: str
     name: str
-    game_compatibility: Set[str]
+    game_compatibility: Set[Flavour]
     folders: Sequence[Sequence[str]]
     download_count: int
-    last_updated: Any
+    last_updated: datetime | int | str
 
 
 class CatalogueEntry(BaseModel):
@@ -123,10 +123,8 @@ class Catalogue(BaseModel):
 
     @classmethod
     async def collate(cls, age_cutoff: datetime | None) -> Catalogue:
-        resolvers = (CurseResolver, WowiResolver, TukuiResolver, InstawowResolver)
-
         async with manager.init_web_client() as web_client:
-            items = [a for r in resolvers async for a in r.collect_items(web_client)]
+            items = [a for r in manager.Manager.RESOLVERS async for a in r.catalogue(web_client)]
 
         normalise = normalise_names()
         most_downloads_per_source = {
@@ -226,7 +224,7 @@ class Resolver:
         raise NotImplementedError
 
     @classmethod
-    async def collect_items(
+    async def catalogue(
         cls, web_client: aiohttp.ClientSession
     ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
         "Yield add-ons from source for cataloguing."
@@ -234,58 +232,58 @@ class Resolver:
         yield
 
 
-if TYPE_CHECKING:
+# Only documenting the fields we're actually using -
+# the API response is absolutely massive
+class CurseAddon_FileDependency(TypedDict):
+    id: int  # Unique dependency ID
+    addonId: int  # The ID of the add-on we're depending on
+    # The type of dependency.  One of:
+    #   1 = embedded library
+    #   2 = optional dependency
+    #   3 = required dependency (this is the one we're after)
+    #   4 = tool
+    #   5 = incompatible
+    #   6 = include (wat)
+    type: int
+    fileId: int  # The ID of the parent file which has this as a dependency
 
-    # Only documenting the fields we're actually using -
-    # the API response is absolutely massive
 
-    class CurseAddon_FileDependency(TypedDict):
-        id: int  # Unique dependency ID
-        addonId: int  # The ID of the add-on we're depending on
-        # The type of dependency.  One of:
-        #   1 = embedded library
-        #   2 = optional dependency
-        #   3 = required dependency (this is the one we're after)
-        #   4 = tool
-        #   5 = incompatible
-        #   6 = include (wat)
-        type: int
-        fileId: int  # The ID of the parent file which has this as a dependency
+class CurseAddon_FileModules(TypedDict):
+    foldername: str
+    fingerprint: int  # Folder fingerprint used by Curse for reconciliation
+    # One of:
+    #   1 = package
+    #   2 = module
+    #   3 = main module
+    #   4 = file
+    #   5 = referenced file
+    # For WoW add-ons the main folder will have type "3" and the rest
+    # of them type "2"
+    type: int
 
-    class CurseAddon_FileModules(TypedDict):
-        foldername: str
-        fingerprint: int  # Folder fingerprint used by Curse for reconciliation
-        # One of:
-        #   1 = package
-        #   2 = module
-        #   3 = main module
-        #   4 = file
-        #   5 = referenced file
-        # For WoW add-ons the main folder will have type "3" and the rest
-        # of them type "2"
-        type: int
 
-    class CurseAddon_File(TypedDict):
-        id: int  # Unique file ID
-        displayName: str  # Tends to be the version
-        downloadUrl: str
-        fileDate: str  # Upload datetime in ISO, e.g. '2020-02-02T12:12:12Z'
-        releaseType: int  # 1 = stable; 2 = beta; 3 = alpha
-        dependencies: list[CurseAddon_FileDependency]
-        modules: list[CurseAddon_FileModules]
-        exposeAsAlternative: bool | None
-        gameVersion: list[str]  # e.g. '8.3.0'
-        gameVersionFlavor: Literal['wow_classic', 'wow_retail']
+class CurseAddon_File(TypedDict):
+    id: int  # Unique file ID
+    displayName: str  # Tends to be the version
+    downloadUrl: str
+    fileDate: str  # Upload datetime in ISO, e.g. '2020-02-02T12:12:12Z'
+    releaseType: int  # 1 = stable; 2 = beta; 3 = alpha
+    dependencies: list[CurseAddon_FileDependency]
+    modules: list[CurseAddon_FileModules]
+    exposeAsAlternative: bool | None
+    gameVersion: list[str]  # e.g. '8.3.0'
+    gameVersionFlavor: Literal['wow_classic', 'wow_retail']
 
-    class CurseAddon(TypedDict):
-        id: int
-        name: str  # User-facing add-on name
-        websiteUrl: str  # e.g. 'https://www.curseforge.com/wow/addons/molinari'
-        summary: str  # One-line description of the add-on
-        downloadCount: int  # Total number of downloads
-        latestFiles: list[CurseAddon_File]
-        slug: str  # URL slug; 'molinari' in 'https://www.curseforge.com/wow/addons/molinari'
-        dateReleased: str  # ISO datetime of latest release
+
+class CurseAddon(TypedDict):
+    id: int
+    name: str  # User-facing add-on name
+    websiteUrl: str  # e.g. 'https://www.curseforge.com/wow/addons/molinari'
+    summary: str  # One-line description of the add-on
+    downloadCount: int  # Total number of downloads
+    latestFiles: list[CurseAddon_File]
+    slug: str  # URL slug; 'molinari' in 'https://www.curseforge.com/wow/addons/molinari'
+    dateReleased: str  # ISO datetime of latest release
 
 
 class CurseResolver(Resolver):
@@ -361,9 +359,11 @@ class CurseResolver(Resolver):
                 label=f'Fetching metadata from {self.name}',
             )
 
-            def is_match(f: CurseAddon_File):
+            def is_version_match(f: CurseAddon_File):
                 return defn.version == f['displayName']
 
+            is_match = is_version_match
+
         else:
 
             files = metadata['latestFiles']
@@ -376,14 +376,16 @@ class CurseResolver(Resolver):
 
             if defn.strategy is Strategy.any_flavour:
 
-                def supports_game_version(f: CurseAddon_File):
+                def supports_any_flavour_game_version(f: CurseAddon_File):
                     return True
 
+                supports_game_version = supports_any_flavour_game_version
+
             else:
                 classic_version_prefix = '1.13'
                 flavour = 'wow_classic' if self.manager.config.is_classic else 'wow_retail'
 
-                def supports_game_version(f: CurseAddon_File):
+                def supports_default_game_version(f: CurseAddon_File):
                     # Files can belong both to retail and classic
                     # but ``gameVersionFlavor`` can only be one of
                     # 'wow_retail' or 'wow_classic'.  To spice things up,
@@ -394,31 +396,44 @@ class CurseResolver(Resolver):
                         for v in f['gameVersion']
                     )
 
+                supports_game_version = supports_default_game_version
+
             if defn.strategy is Strategy.latest:
 
-                def has_release_type(f: CurseAddon_File):
+                def has_latest_release_type(f: CurseAddon_File):
                     return True
 
+                has_release_type = has_latest_release_type
+
             elif defn.strategy is Strategy.curse_latest_beta:
 
-                def has_release_type(f: CurseAddon_File):
+                def has_curse_latest_beta_release_type(f: CurseAddon_File):
                     return f['releaseType'] == 2
 
+                has_release_type = has_curse_latest_beta_release_type
+
             elif defn.strategy is Strategy.curse_latest_alpha:
 
-                def has_release_type(f: CurseAddon_File):
+                def has_curse_latest_alpha_release_type(f: CurseAddon_File):
                     return f['releaseType'] == 3
 
+                has_release_type = has_curse_latest_alpha_release_type
+
             else:
 
-                def has_release_type(f: CurseAddon_File):
+                def has_default_release_type(f: CurseAddon_File):
                     return f['releaseType'] == 1
 
-            def is_match(f: CurseAddon_File):
+                has_release_type = has_default_release_type
+
+            def is_default_matcb(f: CurseAddon_File):
                 return is_not_libless(f) and supports_game_version(f) and has_release_type(f)
 
+            is_match = is_default_matcb
+
         if not files:
             raise E.PkgFileUnavailable('no files available for download')
+
         try:
             file = max(
                 filter(is_match, files),
@@ -427,7 +442,7 @@ class CurseResolver(Resolver):
             )
         except ValueError:
             raise E.PkgFileUnavailable(
-                f'no files compatible with {self.manager.config.game_flavour} '
+                f'no files match {self.manager.config.game_flavour} '
                 f'using {defn.strategy} strategy'
             )
 
@@ -448,13 +463,13 @@ class CurseResolver(Resolver):
         )
 
     @classmethod
-    async def collect_items(
+    async def catalogue(
         cls, web_client: aiohttp.ClientSession
     ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
         classic_version_prefix = '1.13'
 
         def excise_flavours(files: list[CurseAddon_File]):
-            for c in Flavour.__members__:
+            for c in Flavour:
                 if any(f['gameVersionFlavor'] == f'wow_{c}' for f in files):
                     yield c
                 elif any(
@@ -466,7 +481,7 @@ class CurseResolver(Resolver):
 
         step = 1000
         sort_order = '3'  # Alphabetical
-        for index in count(0, step):
+        for index in range(0, 10001 - step, step):
             async with web_client.get(
                 (cls.addon_api_url / 'search').with_query(
                     gameId='1', sort=sort_order, pageSize=step, index=index
@@ -504,7 +519,7 @@ class WowiCommonTerms(TypedDict):
     UIAuthorName: str
 
 
-class WowiCompatibilityEntry(TypedDict):
+class WowiListApiItem_CompatibilityEntry(TypedDict):
     version: str  # Game version, e.g. '8.3.0'
     name: str  # Xpac or patch name, e.g. "Visions of N'Zoth" for 8.3.0
 
@@ -514,7 +529,7 @@ class WowiListApiItem(WowiCommonTerms):
     UIDownloadTotal: str  # Total number of downloads
     UIDownloadMonthly: str  # Number of downloads in the last month and not 'monthly'
     UIFavoriteTotal: str
-    UICompatibility: list[WowiCompatibilityEntry] | None  # ``null`` if would be empty
+    UICompatibility: list[WowiListApiItem_CompatibilityEntry] | None  # ``null`` if would be empty
     UIDir: list[str]  # Names of folders contained in archive
     UIIMG_Thumbs: list[str] | None  # Thumbnail URLs; ``null`` if would be empty
     UIIMGs: list[str] | None  # Full-size image URLs; ``null`` if would be empty
@@ -637,13 +652,13 @@ class WowiResolver(Resolver):
         )
 
     @classmethod
-    async def collect_items(
+    async def catalogue(
         cls, web_client: aiohttp.ClientSession
     ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
         async with web_client.get(cls.list_api_url) as response:
             list_api_items: list[WowiListApiItem] = await response.json()
 
-        flavours = set(Flavour.__members__)
+        flavours = set(Flavour)
         for list_item in list_api_items:
             yield _CatalogueEntryDefaultFields(
                 source=cls.source,
@@ -657,44 +672,43 @@ class WowiResolver(Resolver):
             )
 
 
-if TYPE_CHECKING:
+class TukuiUi(TypedDict):
+    author: str
+    category: str
+    changelog: str
+    donate_url: str
+    downloads: int
+    git: str
+    id: Literal[-1, -2]  # -1 is Tukui and -2 ElvUI
+    lastdownload: str
+    lastupdate: str  # ISO date and no tz, e.g. '2020-02-02'
+    name: str
+    patch: str
+    screenshot_url: str
+    small_desc: str
+    ticket: str
+    url: str
+    version: str
+    web_url: str
 
-    class TukuiUi(TypedDict):
-        author: str
-        category: str
-        changelog: str
-        donate_url: str
-        downloads: int
-        git: str
-        id: Literal[-1, -2]  # -1 is Tukui and -2 ElvUI
-        lastdownload: str
-        lastupdate: str  # ISO date and no tz, e.g. '2020-02-02'
-        name: str
-        patch: str
-        screenshot_url: str
-        small_desc: str
-        ticket: str
-        url: str
-        version: str
-        web_url: str
 
-    class TukuiAddon(TypedDict):
-        author: str
-        category: str
-        changelog: str
-        donate_url: str
-        downloads: str  # Not a mistake, it is actually a string
-        id: str
-        last_download: str
-        # ISO *datetime* with space sep and without an offset, e.g. '2020-02-02 12:12:20'
-        lastupdate: str
-        name: str
-        patch: str | None
-        screenshot_url: str
-        small_desc: str
-        url: str
-        version: str
-        web_url: str
+class TukuiAddon(TypedDict):
+    author: str
+    category: str
+    changelog: str
+    donate_url: str
+    downloads: str  # Not a mistake, it is actually a string
+    id: str
+    last_download: str
+    # ISO *datetime* with space sep and without an offset, e.g. '2020-02-02 12:12:20'
+    lastupdate: str
+    name: str
+    patch: str | None
+    screenshot_url: str
+    small_desc: str
+    url: str
+    version: str
+    web_url: str
 
 
 class TukuiResolver(Resolver):
@@ -785,7 +799,7 @@ class TukuiResolver(Resolver):
         )
 
     @classmethod
-    async def collect_items(
+    async def catalogue(
         cls, web_client: aiohttp.ClientSession
     ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
         async def fetch_ui(ui_slug: str) -> tuple[set[Flavour], list[TukuiUi]]:
@@ -828,33 +842,32 @@ class TukuiResolver(Resolver):
                 )
 
 
-if TYPE_CHECKING:
+# Not exhaustive (as you might've guessed).  Reference:
+# https://docs.github.com/en/rest/reference/repos
+class GithubRepo(TypedDict):
+    name: str  # the repo in user-or-org/repo
+    full_name: str  # user-or-org/repo
+    description: str
+    html_url: str
 
-    # Not exhaustive (as you might've guessed).  Reference:
-    # https://docs.github.com/en/rest/reference/repos
 
-    class GithubRepo(TypedDict):
-        name: str  # the repo in user-or-org/repo
-        full_name: str  # user-or-org/repo
-        description: str
-        html_url: str
+class GithubRelease_Asset(TypedDict):
+    name: str  # filename
+    content_type: str  # mime type
+    state: Literal['starter', 'uploaded']
+    browser_download_url: str
 
-    class GithubReleaseAsset(TypedDict):
-        name: str  # filename
-        content_type: str  # mime type
-        state: Literal['starter', 'uploaded']
-        browser_download_url: str
 
-    class GithubRelease(TypedDict):
-        tag_name: str  # Hopefully the version
-        published_at: str  # ISO datetime
-        assets: list[GithubReleaseAsset]
+class GithubRelease(TypedDict):
+    tag_name: str  # Hopefully the version
+    published_at: str  # ISO datetime
+    assets: list[GithubRelease_Asset]
 
 
 class GithubResolver(Resolver):
     source = 'github'
     name = 'GitHub'
-    strategies = frozenset({Strategy.default, Strategy.version})
+    strategies = frozenset({Strategy.default, Strategy.latest, Strategy.version})
 
     repos_api_url = URL('https://api.github.com/repos')
 
@@ -894,17 +907,28 @@ class GithubResolver(Resolver):
             raise
 
         if defn.strategy is Strategy.version:
-            release_url = repo_url / 'releases/tags' / cast(str, defn.version)
+            assert defn.version
+            release_url = repo_url / 'releases/tags' / defn.version
+        elif defn.strategy is Strategy.latest:
+            release_url = (repo_url / 'releases').with_query(per_page='1')
         else:
+            # Per GH, the latest release is the most recent non-prerelease,
+            # non-draft release, sorted by the ``created_at`` attribute.
+            # https://docs.github.com/en/free-pro-team@latest/rest/reference/repos#get-the-latest-release
             release_url = repo_url / 'releases/latest'
+
         async with self.manager.web_client.get(release_url) as response:
             if response.status == 404:
                 raise E.PkgFileUnavailable('release not found')
-            release_metadata: GithubRelease = await response.json()
+
+            response_json = await response.json()
+            if defn.strategy is Strategy.latest:
+                (response_json,) = response_json
+            release_metadata: GithubRelease = response_json
 
         try:
 
-            def is_valid_asset(asset: GithubReleaseAsset):
+            def is_valid_asset(asset: GithubRelease_Asset):
                 return (
                     # There is something of a convention that Classic archives
                     # end in '-classic' and lib-less archives end in '-nolib'.
@@ -984,7 +1008,7 @@ class InstawowResolver(Resolver):
         )
 
     @classmethod
-    async def collect_items(
+    async def catalogue(
         cls, web_client: aiohttp.ClientSession
     ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
         yield _CatalogueEntryDefaultFields(
@@ -995,7 +1019,119 @@ class InstawowResolver(Resolver):
             folders=[
                 ['WeakAurasCompanion'],
             ],
-            game_compatibility=set(Flavour.__members__),
+            game_compatibility=set(Flavour),
             download_count=1,
             last_updated=datetime.now(timezone.utc),
         )
+
+
+class WowUpHubAddon(TypedDict):
+    id: int
+    repository: str  # Home page URL
+    repository_name: str  # Add-on name
+    source: str
+    description: str  # Includes HTML
+    homepage: str  # Source URL
+    image_url: str
+    owner_image_url: str
+    owner_name: str  # Author
+    total_download_count: int  # Always 0 for Townlong Yak
+    funding_links: list[str]
+    releases: list[WowUpHubAddon_Release]
+
+
+class WowUpHubAddon_Release(TypedDict):
+    body: str  # Changelog?  Includes HTML
+    download_count: int  # Always 0 for Townlong Yak
+    download_url: str
+    external_id: str  # Source ID
+    game_version: str  # TOC-style game version, e.g. "90002" for 9.0.2
+    id: int
+    name: str  # Cf. GH API
+    prerelease: bool
+    published_at: str
+    tag_name: str  # Cf. GH API
+    url: str  # Same as download URL for TY
+    game_type: Literal['retail', 'classic']
+
+
+class WowUpHubAddons(TypedDict):
+    addons: list[WowUpHubAddon]
+
+
+class TownlongYakResolver(Resolver):
+    source = 'townlong-yak'
+    name = 'Townlong Yak (via WowUp.Hub)'
+    strategies = frozenset({Strategy.default})
+
+    _api_url = 'https://hub.wowup.io/addons/author/foxlit'
+
+    @staticmethod
+    def get_alias_from_url(value: str) -> str | None:
+        url = URL(value)
+        if url.host == 'www.townlong-yak.com' and len(url.parts) > 2 and url.parts[1] == 'addons':
+            return url.parts[2]
+
+    async def _synchronise(self) -> dict[str, WowUpHubAddon]:
+        async with self.manager.locks['load Townlong Yak catalogue']:
+            foxlit_addons: WowUpHubAddons = await manager.cache_response(
+                self.manager,
+                self._api_url,
+                {'minutes': 15},
+                label=f'Synchronising {self.name} catalogue',
+            )
+            return {URL(a['repository']).name: a for a in foxlit_addons['addons']}
+
+    async def resolve_one(self, defn: Defn, metadata: None) -> models.Pkg:
+        if defn.strategy not in self.strategies:
+            raise E.PkgStrategyUnsupported(defn.strategy)
+
+        addons = await self._synchronise()
+        try:
+            addon = addons[defn.alias]
+        except KeyError:
+            raise E.PkgNonexistent
+
+        try:
+            file = next(
+                r
+                for r in addon['releases']
+                if not r['prerelease'] and r['game_type'] == self.manager.config.game_flavour
+            )
+        except StopIteration:
+            raise E.PkgFileUnavailable
+
+        return models.Pkg(
+            source=self.source,
+            id=defn.alias,
+            slug=defn.alias,
+            name=addon['repository_name'],
+            description=addon['description'],
+            url=addon['repository'],
+            download_url=file['download_url'],
+            date_published=datetime.now(timezone.utc),
+            version=file['tag_name'],
+            options=models.PkgOptions(strategy=defn.strategy),
+        )
+
+    @classmethod
+    async def catalogue(
+        cls, web_client: aiohttp.ClientSession
+    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+        async with web_client.get(cls._api_url) as response:
+            foxlit_addons: WowUpHubAddons = await response.json()
+
+            for addon in foxlit_addons['addons']:
+                slug = URL(addon['repository']).name
+                yield _CatalogueEntryDefaultFields(
+                    source=cls.source,
+                    id=slug,
+                    slug=slug,
+                    name=addon['repository_name'],
+                    folders=(),
+                    game_compatibility={
+                        Flavour[r['game_type']] for r in addon['releases'] if not r['prerelease']
+                    },
+                    download_count=1,
+                    last_updated=datetime.now(timezone.utc),
+                )
