@@ -10,7 +10,7 @@ from typing import TYPE_CHECKING, Any, ClassVar, Generic, TypeVar
 from loguru import logger
 from pydantic import BaseModel, Field, validator
 from pydantic.generics import GenericModel
-from typing_extensions import Literal, TypedDict
+from typing_extensions import Literal, TypeAlias, TypedDict
 from yarl import URL
 
 from . import manager
@@ -18,33 +18,26 @@ from .config import BaseConfig
 from .utils import bucketise, chain_dict, gather, run_in_thread as t, shasum
 
 if TYPE_CHECKING:
-    ImportString = str
-    RemoteAuras = Sequence[tuple[Sequence[WeakAura], WagoApiResponse, ImportString]]
-
-    _T = TypeVar('_T')
-
-    def type_(value: _T) -> type[_T]:
-        ...
+    from typing_extensions import NotRequired as Ν
 
 
-else:
-    type_ = type
+_ImportString: TypeAlias = str
+RemoteAuras: TypeAlias = 'Sequence[tuple[Sequence[WeakAura], WagoApiResponse, _ImportString]]'
+
+_TWeakAura = TypeVar('_TWeakAura', bound='WeakAura', covariant=True)
+
+IMPORT_API_URL = URL('https://data.wago.io/api/raw/encoded')
 
 
 class BuilderConfig(BaseConfig):
     wago_api_key: typing.Optional[str]
 
 
-WeakAuraT = TypeVar('WeakAuraT', bound='WeakAura')
+class Auras(GenericModel, Generic[_TWeakAura]):
+    api_url: ClassVar[URL]
+    filename: ClassVar[str]
 
-import_api_url = URL('https://data.wago.io/api/raw/encoded')
-
-
-class Auras(GenericModel, Generic[WeakAuraT]):
-    _filename: ClassVar[str]
-    _api_url: ClassVar[URL]
-
-    __root__: typing.Dict[str, typing.List[WeakAuraT]]
+    __root__: typing.Dict[str, typing.List[_TWeakAura]]
 
     class Config:
         arbitrary_types_allowed = True
@@ -53,15 +46,15 @@ class Auras(GenericModel, Generic[WeakAuraT]):
         }
 
     @classmethod
-    def from_lua_table(cls, lua_table: Any) -> Auras[WeakAuraT]:
+    def from_lua_table(cls, lua_table: Any) -> Auras[_TWeakAura]:
         raise NotImplementedError
 
     @classmethod
-    def merge(cls, *auras: Auras[Any]) -> Iterable[Auras[Any]]:
+    def merge(cls, *auras: Auras[_TWeakAura]) -> Iterable[Auras[_TWeakAura]]:
         "Merge auras of the same type."
         return (
             t(__root__=reduce(lambda a, b: {**a, **b}, (i.__root__ for i in a)))
-            for t, a in bucketise(auras, key=type_).items()
+            for t, a in bucketise(auras, key=type).items()
         )
 
 
@@ -82,8 +75,8 @@ class WeakAura(BaseModel):
 
 
 class WeakAuras(Auras[WeakAura]):
-    _filename = 'WeakAuras.lua'
-    _api_url = URL('https://data.wago.io/api/check/weakauras')
+    api_url = URL('https://data.wago.io/api/check/weakauras')
+    filename = 'WeakAuras.lua'
 
     @classmethod
     def from_lua_table(cls, lua_table: Any) -> WeakAuras:
@@ -98,8 +91,8 @@ class Plateroo(WeakAura):
 
 
 class Plateroos(Auras[Plateroo]):
-    _filename = 'Plater.lua'
-    _api_url = URL('https://data.wago.io/api/check/plater')
+    api_url = URL('https://data.wago.io/api/check/plater')
+    filename = 'Plater.lua'
 
     @classmethod
     def from_lua_table(cls, lua_table: Any) -> Plateroos:
@@ -116,32 +109,26 @@ class Plateroos(Auras[Plateroo]):
         return cls(__root__={a.url.parts[1]: [a] for a in sorted_auras})
 
 
-if TYPE_CHECKING:
+class WagoApiResponse_Changelog(TypedDict):
+    format: Ν[Literal['bbcode', 'markdown']]
+    text: Ν[str]
 
-    class WagoApiChangelog(TypedDict, total=False):
-        format: Literal['bbcode', 'markdown']
-        text: str
 
-    class WagoApiCommonFields(TypedDict):
-        _id: str  # +   # Alphanumeric ID
-        name: str  # +  # User-facing name
-        slug: str  # +  # Slug if it has one; otherwise same as ``_id``
-        url: str
-        created: str  # ISO datetime
-        modified: str  # ISO datetime
-        game: str  # "classic" or xpac, e.g. "bfa"
-        username: str  # +  # Author username
-        version: int  # +   # Version counter, incremented with every update
-        # Semver auto-generated from ``version`` - for presentation only
-        versionString: str
-        changelog: WagoApiChangelog  # +
-
-    class WagoApiOptionalFields(TypedDict, total=False):
-        forkOf: str  # Only present on forks
-        regionType: str  # Only present on WAs
-
-    class WagoApiResponse(WagoApiCommonFields, WagoApiOptionalFields):
-        pass
+class WagoApiResponse(TypedDict):
+    _id: str  # +   # Alphanumeric ID
+    name: str  # +  # User-facing name
+    slug: str  # +  # Slug if it has one; otherwise same as ``_id``
+    url: str
+    created: str  # ISO datetime
+    modified: str  # ISO datetime
+    game: str  # "classic" or xpac, e.g. "bfa"
+    username: str  # +  # Author username
+    version: int  # +   # Version counter, incremented with every update
+    # Semver auto-generated from ``version`` - for presentation only
+    versionString: str
+    changelog: WagoApiResponse_Changelog  # +
+    forkOf: Ν[str]  # Only present on forks
+    regionType: Ν[str]  # Only present on WAs
 
 
 class WaCompanionBuilder:
@@ -153,14 +140,14 @@ class WaCompanionBuilder:
         self.builder_config = builder_config
 
     @staticmethod
-    def extract_auras(model: type[Auras[Any]], source: str) -> Auras[Any]:
+    def extract_auras(model: type[Auras[WeakAura]], source: str) -> Auras[WeakAura]:
         from ._custom_slpp import decode
 
         source_after_assignment = source[source.find('=') + 1 :]
         lua_table = decode(source_after_assignment)
         return model.from_lua_table(lua_table)
 
-    def extract_installed_auras(self) -> Iterator[Auras[Any]]:
+    def extract_installed_auras(self) -> Iterator[Auras[WeakAura]]:
         flavour_root = self.manager.config.addon_dir.parents[1]
         saved_vars_of_every_account = flavour_root.glob('WTF/Account/*/SavedVariables')
         for saved_vars, model in product(
@@ -170,7 +157,7 @@ class WaCompanionBuilder:
                 Plateroos,
             ),
         ):
-            file = saved_vars / model._filename
+            file = saved_vars / model.filename
             if not file.exists():
                 logger.info(f'{file} not found')
             else:
@@ -186,7 +173,7 @@ class WaCompanionBuilder:
                     aura_group_cache.write_text(aura_groups.json(), encoding='utf-8')
                 yield aura_groups
 
-    async def get_wago_metadata(self, aura_groups: Auras[Any]) -> list[WagoApiResponse]:
+    async def get_wago_metadata(self, aura_groups: Auras[WeakAura]) -> list[WagoApiResponse]:
         from aiohttp import ClientResponseError
 
         from .manager import cache_response
@@ -196,7 +183,7 @@ class WaCompanionBuilder:
             return sorted(
                 await cache_response(
                     self.manager,
-                    aura_groups._api_url.with_query(ids=','.join(aura_ids)),
+                    aura_groups.api_url.with_query(ids=','.join(aura_ids)),
                     {'minutes': 30},
                     label='Fetching aura metadata',
                     request_extra={'headers': {'api-key': self.builder_config.wago_api_key or ''}},
@@ -213,7 +200,7 @@ class WaCompanionBuilder:
 
         return await cache_response(
             self.manager,
-            import_api_url.with_query(id=aura['_id']),
+            IMPORT_API_URL.with_query(id=aura['_id']),
             {'minutes': 30},
             label=f"Fetching aura '{aura['slug']}'",
             is_json=False,
@@ -221,8 +208,8 @@ class WaCompanionBuilder:
         )
 
     async def get_remote_auras(
-        self, aura_groups: Auras[WeakAuraT]
-    ) -> tuple[type[Auras[WeakAuraT]], RemoteAuras]:
+        self, aura_groups: Auras[WeakAura]
+    ) -> tuple[type[Auras[WeakAura]], RemoteAuras]:
         if not aura_groups.__root__:
             return (aura_groups.__class__, [])
 
@@ -233,7 +220,7 @@ class WaCompanionBuilder:
             [(aura_groups.__root__[r['slug']], r, i) for r, i in zip(metadata, import_strings)],
         )
 
-    def make_addon(self, auras: Sequence[tuple[type[Auras[Any]], RemoteAuras]]) -> None:
+    def make_addon(self, auras: Sequence[tuple[type[Auras[WeakAura]], RemoteAuras]]) -> None:
         from importlib.resources import read_text
         from zipfile import ZipFile, ZipInfo
 
@@ -319,7 +306,7 @@ class WaCompanionBuilder:
             write_tpl('init.lua', {})
             write_tpl(
                 'WeakAurasCompanion.toc',
-                {'interface': '11306' if self.manager.config.is_classic else '90002'},
+                {'interface': '11306' if self.manager.config.is_classic else '90005'},
             )
 
     async def build(self) -> None:
