@@ -16,7 +16,7 @@ inf = float('inf')
 
 
 def pytest_addoption(parser):
-    parser.addoption('--instawow-no-mock', action='store_true')
+    parser.addoption('--iw-no-mock', action='store_true')
 
 
 def should_mock(fn):
@@ -24,9 +24,14 @@ def should_mock(fn):
     import warnings
 
     def wrapper(request):
-        if request.config.getoption('--instawow-no-mock'):
+        if request.config.getoption('--iw-no-mock'):
             warnings.warn('not mocking')
             return None
+        elif any(m.name == 'iw_no_mock' for m in request.node.iter_markers()):
+            return None
+        elif request.module.__name__ == 'test_json_rpc_api':
+            # aresponses conflicts with aiohttp's own test server
+            return None
 
         args = (request.getfixturevalue(p) for p in inspect.signature(fn).parameters)
         return fn(*args)
@@ -80,7 +85,9 @@ async def iw_web_client():
 
 @pytest.fixture
 def iw_manager(iw_config, iw_web_client):
-    yield Manager.from_config(iw_config, web_client=iw_web_client)
+    manager = Manager.from_config(iw_config)
+    manager.contextualise(web_client=iw_web_client)
+    yield manager
 
 
 @pytest.fixture
@@ -243,6 +250,14 @@ def mock_github(aresponses):
         read_json_fixture('github-release-lib-and-nolib.json'),
         repeat=inf,
     )
+    aresponses.add(
+        'api.github.com',
+        '/repos/AdiAddons/AdiButtonAuras/releases?per_page=1',
+        'get',
+        [read_json_fixture('github-release-lib-and-nolib.json')],
+        match_querystring=True,
+        repeat=inf,
+    )
     aresponses.add(
         'api.github.com',
         '/repos/AdiAddons/AdiButtonAuras/releases/tags/2.1.0',
@@ -303,6 +318,25 @@ def mock_github(aresponses):
 
 @pytest.fixture
 @should_mock
+def mock_townlong_yak(aresponses):
+    aresponses.add(
+        'hub.wowup.io',
+        '/addons/author/foxlit',
+        'get',
+        read_json_fixture('wowup-hub-townlong-yak.json'),
+        repeat=inf,
+    )
+    aresponses.add(
+        'www.townlong-yak.com',
+        re.compile(r'^/addons/ul/[0-9a-z]{41}/install\.zip'),
+        'get',
+        aresponses.Response(body=make_addon_zip('Foo')),
+        repeat=inf,
+    )
+
+
+@pytest.fixture(autouse=True)
+@should_mock
 def mock_all(
     mock_pypi,
     mock_master_catalogue,
@@ -310,5 +344,6 @@ def mock_all(
     mock_wowi,
     mock_tukui,
     mock_github,
+    mock_townlong_yak,
 ):
     pass
